<?php
/* --------------------------------------------------------------
   dependent.inc.php 2017-05-31
   Gambio GmbH
   http://www.gambio.de
   Copyright © 2017 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

/**
 * Add configuration default value for index suppression in SEO Boost config
 */
$check = $this->query('SELECT * FROM `gm_configuration` WHERE `gm_key` = "SUPPRESS_INDEX_IN_URL"', true);
if($check->num_rows === 0)
{
	$query = 'INSERT INTO `gm_configuration` 
				SET gm_key = "SUPPRESS_INDEX_IN_URL", 
					gm_value = "true"';
	$t_success &= $this->query($query, true);
}


/**
 * Static SEO URLs
 */
$t_success &= $this->query("CREATE TABLE IF NOT EXISTS `static_seo_urls` (
  `static_seo_url_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(255) NOT NULL DEFAULT '',
  `sitemap_entry` int(1) NOT NULL DEFAULT '0',
  `priority` varchar(3) NOT NULL DEFAULT '0.5',
  `changefreq` varchar(255) NOT NULL DEFAULT 'weekly',
  `robots_disallow_entry` int(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`static_seo_url_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8", true);

$t_success &= $this->query("CREATE TABLE IF NOT EXISTS `static_seo_url_contents` (
  `static_seo_url_content_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `static_seo_url_id` int(11) DEFAULT NULL,
  `language_id` int(11) DEFAULT NULL,
  `title` varchar(255) NOT NULL DEFAULT '0',
  `description` text NOT NULL,
  `keywords` text NOT NULL,
  PRIMARY KEY (`static_seo_url_content_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8", true);

$staticSeoUrls = [
	['url' => 'specials.php', 'robots_disallow_entry' => 0],
	['url' => 'products_new.php', 'robots_disallow_entry' => 0],
	['url' => 'login.php', 'robots_disallow_entry' => 1],
	['url' => 'password_double_opt.php', 'robots_disallow_entry' => 1],
	['url' => 'wish_list.php', 'robots_disallow_entry' => 1],
	['url' => 'shopping_cart.php', 'robots_disallow_entry' => 1],
	['url' => 'advanced_search_result.php', 'robots_disallow_entry' => 1],
	['url' => 'advanced_search.php', 'robots_disallow_entry' => 1],
	['url' => 'newsletter.php', 'robots_disallow_entry' => 1],
];

foreach($staticSeoUrls as $staticSeoUrl)
{
	$check = $this->query('SELECT * FROM `static_seo_urls` WHERE `name` = "' . $staticSeoUrl['url'] . '"', true);
	if($check->num_rows === 0)
	{
		$query = "
			INSERT INTO `static_seo_urls` 
				(`name`, `robots_disallow_entry`) 
			VALUES 
				('" . $staticSeoUrl['url'] . "', " . $staticSeoUrl['robots_disallow_entry'] . ")
		";
		
		$t_success &= $this->query($query, true);
	}
}


/**
 * Change module shipping alias of Deutsche Post (DP)
 */
$check = $this->query('SELECT * FROM `configuration` WHERE `configuration_key` = "MODULE_SHIPPING_DP_ALIAS" AND `configuration_value` = "DPD"', true);
if($check->num_rows !== 0)
{
	$query = 'UPDATE `configuration` SET `configuration_value` = "DHL" WHERE `configuration_key` = "MODULE_SHIPPING_DP_ALIAS";';
	$t_success &= $this->query($query, true);
}


/**
 * Add gm_key GRADUATED_ASSIGN if needed
 */
$check = $this->query('SELECT * FROM `gm_configuration` WHERE `gm_key` = "GRADUATED_ASSIGN"', true);
if($check->num_rows === 0)
{
	$query = 'INSERT INTO `gm_configuration` SET `gm_key` = "GRADUATED_ASSIGN", `gm_value` = "1";';
	$t_success &= $this->query($query, true);
}


/**
 * Increase varchar-value to 39 for IPv6
 */
$t_check = $this->table_column_exists('orders', 'customers_ip');
if($t_check)
{
	$query = 'ALTER TABLE `orders` MODIFY `customers_ip` varchar(39) NOT NULL DEFAULT ""';
	$t_success &= $this->query($query, true);
}


/**
 * Add "export_all_new_ones" column to export_schemes. Needed for the new export option "Always export new categories".
 */
$t_check = $this->table_exists('export_schemes');
$t_check2 = $this->table_column_exists('export_schemes', 'export_all_new_ones');
if($t_check && !$t_check2)
{
	$query = 'ALTER TABLE `export_schemes` ADD `export_all_new_ones` tinyint(1) NOT NULL DEFAULT 0';
	$t_success &= $this->query($query, true);
}


/**
 * Add "export_property_image" column to export_schemes. Needed for the new export option "Export property image instead of product image".
 */
$t_check = $this->table_exists('export_schemes');
$t_check2 = $this->table_column_exists('export_schemes', 'export_property_image');
if($t_check && !$t_check2)
{
	$query = 'ALTER TABLE `export_schemes` ADD `export_property_image` tinyint(1) NOT NULL DEFAULT 0';
	$t_success &= $this->query($query, true);
}


/**
 * Add "amount_export_image_files" column to export_schemes. Needed for the new export option "Amount of additional images".
 * (Will be only used in google shopping.)
 */
$t_check = $this->table_exists('export_schemes');
$t_check2 = $this->table_column_exists('export_schemes', 'amount_additional_image_files');
if($t_check && !$t_check2)
{
	$query = 'ALTER TABLE `export_schemes` ADD `amount_additional_image_files` INT NOT NULL DEFAULT 99999';
	$t_success &= $this->query($query, true);
}
// Set this value to 10 for google shopping
$check = $this->query('SELECT * FROM `export_schemes` WHERE `scheme_id` = "1"', true);
if($check->num_rows === 1)
{
	$query = 'UPDATE `export_schemes` SET `amount_additional_image_files` = "10" WHERE `scheme_id` = "1";';
	$t_success &= $this->query($query, true);
}


/**
 * Add "about us" and "search" to content manager (only for english, they already exist in german)
 */
$check = $this->query('SELECT * FROM `content_manager` WHERE `content_group` = 30 AND `languages_id` = 1', true);
if($check->num_rows === 0)
{
	$query = "INSERT INTO `content_manager` (`categories_id`, `parent_id`, `group_ids`, `languages_id`, `content_title`, `content_heading`, `content_text`, `sort_order`, `file_flag`, `content_file`, `download_file`, `content_status`, `content_group`, `content_delete`, `gm_link`, `gm_link_target`, `gm_priority`, `gm_changefreq`, `gm_last_modified`, `gm_sitemap_entry`, `gm_robots_entry`, `gm_url_keywords`, `protected`) VALUES(0, 0, '', 1, 'Search', '', '', 0, 3, '', '', 0, 30, 1, 'advanced_search.php', '_top', '0.0', 'always', '2008-07-30 04:24:06', 0, 0, '', 0);";
	$t_success &= $this->query($query, true);
}
$check = $this->query('SELECT * FROM `content_manager` WHERE `content_group` = 82 AND `languages_id` = 1', true);
if($check->num_rows === 0)
{
	$query = "INSERT INTO `content_manager` (`categories_id`, `parent_id`, `group_ids`, `languages_id`, `content_title`, `content_heading`, `content_text`, `sort_order`, `file_flag`, `content_file`, `download_file`, `content_status`, `content_group`, `content_delete`, `gm_link`, `gm_link_target`, `gm_priority`, `gm_changefreq`, `gm_last_modified`, `gm_sitemap_entry`, `gm_robots_entry`, `gm_url_keywords`, `protected`) VALUES(0, 0, '', 1, 'About us', 'About us', '<p>Fill in the informations about you or your corporation</p>', 1, 3, '', '', 0, 82, 1, '', '_blank', '0.0', 'always', '2008-08-25 17:57:47', 0, 0, '', 0);";
	$t_success &= $this->query($query, true);
}


$t_success &= $this->set_index('gm_gprint_orders_elements', 'INDEX', array('gm_gprint_orders_surfaces_id'),
                               'gm_gprint_orders_surfaces_id');
$t_success &= $this->set_index('gm_gprint_orders_surfaces', 'INDEX', array('gm_gprint_orders_surfaces_groups_id'),
                               'gm_gprint_orders_surfaces_groups_id');


/**
 * In some countries, federal states are always necessary.
 */

$t_check = $this->table_column_exists('countries', 'is_state_mandatory');
if(!$t_check)
{
	$query = 'ALTER TABLE countries ADD COLUMN is_state_mandatory INT DEFAULT 0';
	$t_success &= $this->query($query, true);
}

/**
 * Change the length of the column zone_name of the table zones so that longer zone names can be inserted.
 */

$t_check = $this->table_column_exists('zones', 'zone_name');
if(!$t_check)
{
	$query = 'ALTER TABLE zones MODIFY zone_name VARCHAR(128)';
	$t_success &= $this->query($query, true);
}
